==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_abm = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "abm", {
        get: function () {
            return this.get_abm();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.ab9 = function () {
        return true;
    };
    ItemwiseStrategyBasedIndicator.prototype.ab0 = function () {
        _super.prototype.ab0.call(this);
        this.ab7 = this.ab8;
        this.abl.c = this.ab7;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/ItemwiseStrategyBasedIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { ItemwiseStrategyCalculationStrategy } from "./ItemwiseStrategyCalculationStrategy";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var ItemwiseStrategyBasedIndicator = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ItemwiseStrategyBasedIndicator, _super);
    function ItemwiseStrategyBasedIndicator() {
        return _super.call(this) || this;
    }
    ItemwiseStrategyBasedIndicator.prototype.get_abv = function () {
        return new ItemwiseStrategyCalculationStrategy();
    };
    Object.defineProperty(ItemwiseStrategyBasedIndicator.prototype, "abv", {
        get: function () {
            return this.get_abv();
        },
        enumerable: false,
        configurable: true
    });
    ItemwiseStrategyBasedIndicator.prototype.aci = function () {
        return true;
    };
    ItemwiseStrategyBasedIndicator.prototype.ab9 = function () {
        _super.prototype.ab9.call(this);
        this.acg = this.ach;
        this.abu.c = this.acg;
    };
    ItemwiseStrategyBasedIndicator.$t = markType(ItemwiseStrategyBasedIndicator, 'ItemwiseStrategyBasedIndicator', StrategyBasedIndicator.$);
    return ItemwiseStrategyBasedIndicator;
}(StrategyBasedIndicator));
export { ItemwiseStrategyBasedIndicator };
